pub struct LcfMapUnit {
pub chipset: u32,
pub width: u32,
pub height: u32,
pub scroll_type: ScrollType,
pub panorama: Panorama,
pub lower: Vec<u16>,
pub upper: Vec<u16>,
pub events: Vec<Event>,
pub save_time: u32,
}Fields
chipset: u32ID of the tileset to use for the upper and lower layers.
- Default: 1.
width: u32Width of the map in tiles.
- Minimum: 20 (size of screen).
- Maximum: 500.
Exceeding this range causes no problems.
height: u32Height of the map in tiles.
- Minimum: 15 (size of screen).
- Maximum: 500.
Exceeding this range causes no problems.
scroll_type: ScrollTypepanorama: Panoramalower: Vec<u16>Length must match the Self::width * Self::height
upper: Vec<u16>Length must match the Self::width * Self::height
events: Vec<Event>save_time: u32Trait Implementations
Sourceimpl Clone for LcfMapUnit
impl Clone for LcfMapUnit
Sourcefn clone(&self) -> LcfMapUnit
fn clone(&self) -> LcfMapUnit
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConvertExt for LcfMapUnit
impl ConvertExt for LcfMapUnit
Sourceimpl Debug for LcfMapUnit
impl Debug for LcfMapUnit
Sourceimpl Default for LcfMapUnit
impl Default for LcfMapUnit
Sourceimpl<'de> Deserialize<'de> for LcfMapUnit
impl<'de> Deserialize<'de> for LcfMapUnit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&LcfMapUnit> for RawLcfMapUnit
impl From<&LcfMapUnit> for RawLcfMapUnit
Sourcefn from(val: &LcfMapUnit) -> Self
fn from(val: &LcfMapUnit) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for LcfMapUnit
impl PartialEq for LcfMapUnit
Sourceimpl Serialize for LcfMapUnit
impl Serialize for LcfMapUnit
Sourceimpl TryFrom<RawLcfMapUnit> for LcfMapUnit
impl TryFrom<RawLcfMapUnit> for LcfMapUnit
Sourcetype Error = LcfMapUnitReadError
type Error = LcfMapUnitReadError
The type returned in the event of a conversion error.
impl Eq for LcfMapUnit
impl StructuralPartialEq for LcfMapUnit